==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterImageSetReferenceBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterImageSetReferenceBuilder extends ClusterImageSetReferenceFluentImpl<ClusterImageSetReferenceBuilder> implements VisitableBuilder<ClusterImageSetReference,ClusterImageSetReferenceBuilder>{
  public ClusterImageSetReferenceBuilder() {
    this(false);
  }
  public ClusterImageSetReferenceBuilder(Boolean validationEnabled) {
    this(new ClusterImageSetReference(), validationEnabled);
  }
  public ClusterImageSetReferenceBuilder(ClusterImageSetReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterImageSetReferenceBuilder(ClusterImageSetReferenceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterImageSetReference(), validationEnabled);
  }
  public ClusterImageSetReferenceBuilder(ClusterImageSetReferenceFluent<?> fluent,ClusterImageSetReference instance) {
    this(fluent, instance, false);
  }
  public ClusterImageSetReferenceBuilder(ClusterImageSetReferenceFluent<?> fluent,ClusterImageSetReference instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterImageSetReferenceBuilder(ClusterImageSetReference instance) {
    this(instance,false);
  }
  public ClusterImageSetReferenceBuilder(ClusterImageSetReference instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterImageSetReferenceFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterImageSetReference build() {
    ClusterImageSetReference buildable = new ClusterImageSetReference(fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterImageSetReferenceBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterImageSetReferenceBuilder extends ClusterImageSetReferenceFluent<ClusterImageSetReferenceBuilder> implements VisitableBuilder<ClusterImageSetReference,ClusterImageSetReferenceBuilder>{
  public ClusterImageSetReferenceBuilder() {
    this(false);
  }
  public ClusterImageSetReferenceBuilder(Boolean validationEnabled) {
    this(new ClusterImageSetReference(), validationEnabled);
  }
  public ClusterImageSetReferenceBuilder(ClusterImageSetReferenceFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterImageSetReferenceBuilder(ClusterImageSetReferenceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterImageSetReference(), validationEnabled);
  }
  public ClusterImageSetReferenceBuilder(ClusterImageSetReferenceFluent<?> fluent,ClusterImageSetReference instance) {
    this(fluent, instance, false);
  }
  public ClusterImageSetReferenceBuilder(ClusterImageSetReferenceFluent<?> fluent,ClusterImageSetReference instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ClusterImageSetReference());

    if (instance != null) {
      fluent.withName(instance.getName());
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterImageSetReferenceBuilder(ClusterImageSetReference instance) {
    this(instance,false);
  }
  public ClusterImageSetReferenceBuilder(ClusterImageSetReference instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ClusterImageSetReference());

    if (instance != null) {
      this.withName(instance.getName());
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterImageSetReferenceFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterImageSetReference build() {
    ClusterImageSetReference buildable = new ClusterImageSetReference(fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
